#
# spec file for package python-jupyter-packaging
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-jupyter-packaging
Version:        0.12.3
Release:        4.1
Summary:        Jupyter Packaging Utilities
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jupyter/jupyter-packaging
Source:         https://files.pythonhosted.org/packages/source/j/jupyter_packaging/jupyter_packaging-%{version}.tar.gz
# PATCH-FIX-UPSTREAM jupyter-packaging-pr178-ignoredeprecations.patch gh#jupyter/jupyter-packaging#178
Patch0:         https://github.com/jupyter/jupyter-packaging/pull/178.patch#/jupyter-packaging-pr178-ignoredeprecations.patch
# PATCH-FIX-UPSTREAM jupyter-packaging-pr186-bdist_wheel.patch gh#jupyter/jupyter-packaging#186
Patch1:         jupyter-packaging-pr186-bdist_wheel.patch
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module deprecation}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 60.2}
BuildRequires:  %{python_module tomlkit}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-deprecation
Requires:       python-packaging
Requires:       python-setuptools >= 60.2
Requires:       python-tomlkit
Requires:       python-wheel
Provides:       python-jupyter_packaging = %{version}-%{release}
# SECTION test requirements
BuildRequires:  %{python_module build}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest}
#/SECTION
BuildArch:      noarch
%python_subpackages

%description
This package contains utilities for making Python packages
with and without accompanying JavaScript packages

%prep
%autosetup -p1 -n jupyter_packaging-%{version}
sed -i 's/\r$//' README.md
sed -i -e '/^#!\//, 1d' jupyter_packaging/*.py
sed -i 's/--color=yes//' pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# tests call pip which wants to check the online cache
donttest="test_install or test_datafiles_install"
donttest+=" or test_build_api and (test_build_package or test_deprecated_metadata)"
# want to write into system sitelib
donttest+=" or test_create_cmdclass"
# calls python (=python2)
donttest+=" or test_run"
%pytest -k "not ($donttest)"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/jupyter_packaging
%{python_sitelib}/jupyter_packaging-%{version}.dist-info

%changelog
* Thu Feb 27 2025 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Sep 16 2024 Ben Greiner <code@bnavigator.de>
- Add jupyter-packaging-pr186-bdist_wheel.patch
  * gh#jupyter/jupyter-packaging#186
  * gh#jupyter/jupyter-packaging#185
* Sat Apr  1 2023 Ben Greiner <code@bnavigator.de>
- Add jupyter-packaging-pr178-ignoredeprecations.patch
  * gh#jupyter/jupyter-packaging#178
  * Fixes deprecation warnings through new setuptools
* Thu Sep  8 2022 Arun Persaud <arun@gmx.de>
- update to version 0.12.3
  * only remove --skip-npm from argv if it is here #161 (@videlec)
* Wed Jul 13 2022 Ben Greiner <code@bnavigator.de>
- Fix spec-cleaner gone wrong
- Update requirements
* Wed Jul 13 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * remove skip python version 2 (got base>=3.7 anyway)
  * switch to pyproject build
  * require hatchling, pip, pytest-timeout
- update to version 0.12.2:
  * Maintenance and upkeep improvements
    + Replace deprecated pipes.quote with shlex.quote #153 (@hroncok)
    + [pre-commit.ci] pre-commit autoupdate #152 (@pre-commit-ci)
    + [pre-commit.ci] pre-commit autoupdate #151 (@pre-commit-ci)
- changes from version 0.12.1:
  * Enhancements made
    + Allow skipping npm with JUPYTER_PACKAGING_SKIP_NPM env #133
    (@minrk)
  * Maintenance and upkeep improvements
    + [pre-commit.ci] pre-commit autoupdate #149 (@pre-commit-ci)
    + Auto label bot PRs #148 (@blink1073)
    + Use hatch backend #147 (@blink1073)
    + [pre-commit.ci] pre-commit autoupdate #146 (@pre-commit-ci)
    + Use flit build backend #144 (@blink1073)
    + [pre-commit.ci] pre-commit autoupdate #142 (@pre-commit-ci)
    + [pre-commit.ci] pre-commit autoupdate #141 (@pre-commit-ci)
    + [pre-commit.ci] pre-commit autoupdate #140 (@pre-commit-ci)
    + Update pre-commit #139 (@blink1073)
    + Clean up CI and Tests #137 (@blink1073)
  * Other merged PRs
    + do not install tests as a top-level package #135 (@mgorny)
- changes from version 0.12.0:
  * Bugs fixed
    + Update import for new setuptools path (setuptools >=61.0.0) #131
    (@timkpaine)
    + Use pathlib rather than os.path #125 (@fcollonval)
  * Maintenance and upkeep improvements
    + Add source URL to pypi project page #129 (@manics)
    + Add pre-commit #126 (@fcollonval)
    + Stop using distutils.log #123 (@blink1073)
* Sun Nov 21 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.11.1
  * Fix running testsuite within virtualenv #111 (@jnahmias)
* Fri Nov 12 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.11.0
  * Drop support for Python 3.6 and add support for Python 3.10
* Sun Oct 17 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.10.6
  * The import of bdist_wheel is optional, must check for None
    before using it #106 (@ellert)
- Release 0.10.5
  * Fix last one hardcoded unversioned python command #98
    (@frenzymadness)
  * Add note about using the build package #104 (@blink1073)
- Release 0.10.4
  * Handle missing yarn #99 (@blink1073)
* Fri Jun 25 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.10.3
  * Some fixes for issues discovered during packaging #96
    (@frenzymadness)
  * Disallow deprecated function return incorrect results for
    Python 3.10 #97 (@frenzymadness)
  * Fix handling of module metadata in tests #92 (@blink1073)
- Release 0.10.2
  * Fix Handling of npm Parameter #90 (@jtpio)
- Release 0.10.1
  * Fix Handling of Skip If Exists #86 (@jtpio)
- Release 0.10.0
  * Add more options to Build #84 (@jtpio)
- Release 0.9.2
  * Clean up handling of version info #82 (@jtpio)
* Fri Apr 16 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.9.1
  * Do not run ensure_targets in develop mode #79 (@jtpio)
- Release 0.9.0
  * Add ability to ensure targets #77 (@jtpio)
  * Add version info helper function #76 (@afshin)
- Release 0.8.3
  * Fixes handling of backend #75 (@jtpio)
- Release 0.8.2
  * Fix invalid command build #72 (@xmnlab)
- Release 0.8.1
  * Fix Usage of install_npm #71 (@afshin)
- Release 0.8.0
  * Proposal: Improved integration with setuptools #69 (@afshin)
  * Update changelog #68 (@blink1073)
* Mon Mar  1 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.7.12
  * no newer release notes
- Release 0.6
  * Move data files to the correct place on develop install #41
- Release 0.5
  * Update readme to mention pep 518 #36
  * Add handling of data_files in develop mode and add test. #35
- Drop which-finds-python-executable.patch merged upstream
* Tue May  5 2020 Marketa Calabkova <mcalabkova@suse.com>
- Add patch which-finds-python-executable.patch to fix tests
- Spec-cleaner fixes
* Mon Nov 18 2019 Todd R <toddrme2178@gmail.com>
- Initial version
